@@ -20,9 +20,8 @@
 #include <fmp4/mp4_options.h>
 #include <fmp4/moov.h>
 #include <fmp4/output_bucket.h>
-#include <fmp4/mp4_pubpoint.h>
 #include <fmp4/mp4_handler_io.h>
-#include <fmp4/http_util.h>
+#include <fmp4/post_handler.h>
 
 #if 0
 /* Mod-H264-Streaming configuration
@@ -1078,7 +1077,7 @@ ngx_streaming_handler_post(ngx_http_request_t *r, mp4_process_context_t* ctx)
                 "ngx_streaming_handler_post: manifest=%s",
                 (char const*)ctx->filename_);
 
-  post_handler_t* post_handler = pubpoint_create_post_handler(ctx);
+  post_handler_t* post_handler = create_post_handler(ctx);
 
   if(post_handler == NULL)
   {
